==> drupalmoduleupgrader-8.x-0.6.tar.gz: drupalmoduleupgrader/src/Plugin/DMU/Converter/Functions/EntityOperationDeriver.php <==
<?php

namespace Drupal\drupalmoduleupgrader\Plugin\DMU\Converter\Functions;

use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\drupalmoduleupgrader\DeriverBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Builds derivative definitions for the _entity_operation plugin, allowing us to
 * rewrite calls to things like entity_save(), node_delete(), entity_label(), etc.
 */
class EntityOperationDeriver extends DeriverBase implements ContainerDeriverInterface {

  /**
   * @var \Drupal\Core\StringTranslation\TranslationInterface
   */
  protected $translator;

  /**
   * @var array
   */
  protected $config;

  public function __construct(TranslationInterface $translator, array $config) {
    $this->translator = $translator;
    $this->config = $config;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('string_translation'),
      $container->get('config.factory')->get('drupalmoduleupgrader.entity_operations')->get()
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_definition) {
    $derivatives = [];

    foreach ($this->config as $entity_type => $operations) {
      foreach ($operations as $operation) {
        $function = $entity_type . '_' . $operation;
        $variables = [
          '@function' => $function,
          '@operation' => $operation,
        ];
        $derivative = $base_definition;
        $derivative['function'] = $function;
        $derivative['method'] = $operation;
        $derivative['message'] = $this->translator
          ->translate('`@function` is now `EntityInterface::@operation`.', $variables);
        $derivative['description'] = $this->translator
          ->translate('Rewrites calls to @function().', $variables);
        $derivatives[$function] = $derivative;
      }
    }

    return $derivatives;
  }

}

==> drupalmoduleupgrader-8.x-0.7.tar.gz: drupalmoduleupgrader/src/Plugin/DMU/Converter/Functions/EntityOperationDeriver.php <==
<?php

namespace Drupal\drupalmoduleupgrader\Plugin\DMU\Converter\Functions;

use Drupal\Core\Plugin\Discovery\ContainerDeriverInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\drupalmoduleupgrader\DeriverBase;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Builds derivative definitions for the _entity_operation plugin, allowing us to
 * rewrite calls to things like entity_save(), node_delete(), entity_label(), etc.
 */
class EntityOperationDeriver extends DeriverBase {

  /**
   * @var array
   */
  protected $config;

  public function __construct(TranslationInterface $translator, array $config) {
    parent::__construct($translator);
    $this->config = $config;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, $base_plugin_id) {
    return new static(
      $container->get('string_translation'),
      $container->get('config.factory')->get('drupalmoduleupgrader.entity_operations')->get()
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_definition) {
    $derivatives = [];

    foreach ($this->config as $entity_type => $operations) {
      foreach ($operations as $operation) {
        $function = $entity_type . '_' . $operation;
        $variables = [
          '@function' => $function,
          '@operation' => $operation,
        ];
        $derivative = $base_definition;
        $derivative['function'] = $function;
        $derivative['method'] = $operation;
        $derivative['message'] = $this->t('`@function` is now `EntityInterface::@operation`.', $variables);
        $derivative['description'] = $this->t('Rewrites calls to @function().', $variables);
        $derivatives[$function] = $derivative;
      }
    }

    return $derivatives;
  }

}
